# package_name

Description. 
The package package_name is used to:
	Este pacote foi criado para fim educacional ,para elucidar a criacao de pacotes  
	-o projeto original e de https://github.com/ubiratan-motta e tambem da instrutora da Dio Karina tiemi 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_name
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
Gacavalc

## License

